package ru.dsi.bgbilling.modules.inet.accounting.detail;

import bitel.billing.common.TimeUtils;
import ru.bitel.bgbilling.common.BGException;
import ru.bitel.bgbilling.modules.inet.accounting.detail.InetFlowDetailMaker;
import ru.bitel.bgbilling.modules.inet.accounting.detail.event.InetDetailCreateEvent;
import ru.bitel.bgbilling.server.util.DefaultServerSetup;
import ru.bitel.common.sql.ConnectionSet;
import ru.dsi.bgbilling.modules.inet.accounting.detail.bean.ClientDetailUtils;
import ru.dsi.bgbilling.modules.inet.accounting.detail.event.InetClientDetailCreateEvent;

import java.io.File;
import java.io.FileOutputStream;
import java.io.OutputStream;
import java.util.List;

/**
 * Класс переопределяет метод отправки файла детализации sendDetailImpl стандартного класса InetFlowDetailMaker
 * Вместо отпрвки на email сохраняем файл в директорию [detail.client.dir]/[cid]/
 * Конфигурация в inet-accounting.xml:
 * <application context="accounting">
 *     ...
 *     <param name="detail.client.dir" value="/usr/local/ipdetail" />
 *     ...
 *
 *     <context name="collector">
 *         <context name="detail">
 *             <!-- Cоздание обработчика flow детализации -->
 *             <bean name="detailWorker" class="ru.bitel.bgbilling.modules.inet.accounting.detail.InetDetailWorker"/>
 *             <!-- Собственный обработчик flow детализации из ЛК-->
 *             <bean name="clientDetailWorker" class="ru.dsi.bgbilling.modules.inet.accounting.detail.InetClientDetailWorker"/>
 *         </context>
 *     </context>
 *
 * </application>
 */
@SuppressWarnings("ResultOfMethodCallIgnored")
public class InetFlowClientDetailMaker extends InetFlowDetailMaker
{
    /**
     * Сохраняем только на диск - на email не высылаем
     * @param messageBody not used
     * @param subject not used
     * @throws Exception
     */
    protected void sendDetailImpl(
            DefaultServerSetup setup,
            ConnectionSet connectionSet,
            InetDetailCreateEvent task,
            List<FlowDetailEntry> entries,
            StringBuilder messageBody,
            String subject) throws Exception
    {
        int cid;
        if(task instanceof InetClientDetailCreateEvent){
            cid = ((InetClientDetailCreateEvent) task).getRequestCid();
        }else{
            throw new BGException("task event is not an InetClientDetailCreateEvent");
        }

        String filename = String.valueOf(task.getInetServId()) + "_";
        if(TimeUtils.daysDelta(task.getTimeFrom(), task.getTimeTo())>1){
            filename = filename + TimeUtils.format(task.getTimeFrom(), "yyyyMMdd'T'HHmmss")+ "-" + TimeUtils.format(task.getTimeTo(), "yyyyMMdd'T'HHmmss");
        }else{
            filename = filename + TimeUtils.format(task.getTimeFrom(), "yyyyMMdd");
        }


        File dir = new File(setup.get("detail.client.dir", "data/client"), String.valueOf(cid));
        dir.mkdirs();
        File file = new File(dir, filename+ ".zip.tmp");
        OutputStream os = new FileOutputStream(file);

        writeDetailImpl(setup, connectionSet, task, entries, messageBody, subject, os, false);

        os.flush();

        file.renameTo(new File(file.getParentFile(), file.getName().substring(0, file.getName().length() - 4)));

        //Выполнили задание - удаляем отметку из базы
        ClientDetailUtils.removeTask(cid, connectionSet.getConnection());
    }
}