package ru.dsi.bgbilling.modules.inet.accounting.detail.bean;

import bitel.billing.common.TimeUtils;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.Date;

/**
 * Управление таблицей, в которой храним информацию о заказах детализации из Web-статистики по cid договора
 * Простая справочная информация: cid -> время последнего заказа
 *
 * Требуется таблица:
 * CREATE TABLE `custom_inet_client_detail_task` (
 * `cid` int(11) NOT NULL,
 * `dt` datetime NOT NULL,
 * PRIMARY KEY (`cid`)
 * )
 */
public class ClientDetailUtils{
    final static String table = "custom_inet_client_detail_task";

    public static void registerTask(int cid, Connection con) throws SQLException {
        PreparedStatement ps = con.prepareStatement("insert into "+table+" (cid, dt) values(?,now()) on duplicate key update dt=now()");
        ps.setInt(1, cid);
        ps.executeUpdate();
        ps.close();
    }

    public static void removeTask(int cid, Connection con) throws SQLException {
        PreparedStatement ps = con.prepareStatement("delete from "+table+" where cid=?");
        ps.setInt(1, cid);
        ps.executeUpdate();
        ps.close();
    }

    public static Date getTaskDt(int cid, Connection con) throws SQLException {
        Date result = null;
        PreparedStatement ps = con.prepareStatement("select dt from "+table+" where cid=?");
        ps.setInt(1, cid);
        ResultSet rs = ps.executeQuery();
        if(rs.next()){
            result = TimeUtils.convertTimestampToDate(rs.getTimestamp(1));
        }
        rs.close();
        ps.close();
        return result;
    }
}